@@ -1,13 +1,14 @@
 use super::*;
-use auto_impl::auto_impl;
 use std::collections::*;
 use std::ffi::CString;
 
 #[cfg(feature = "url")]
 use url_inner::Url;
 
+#[cfg(feature = "semver")]
+use semver_inner::{Version, VersionReq};
+
 /// # Implements base to be parsed by [Sparse](crate)
-#[auto_impl(&mut, Box)]
 pub trait Sparsable {
     /// Initialize recusively a [Sparsable](Sparsable) pointer
     fn sparse_init(
@@ -29,7 +30,7 @@ pub trait Sparsable {
 
     /// Check if the current depth isn't too much.
     /// This is the cyclic pointer protection mechanism
-    fn check_depth(depth: u32) -> Result<(), SparseError> {
+    fn check_depth(&self, depth: u32) -> Result<(), SparseError> {
         match depth < MAX_SPARSE_DEPTH {
             true => Ok(()),
             false => Err(SparseError::CyclicRef),
@@ -64,6 +65,41 @@ impl Sparsable for Url {
     }
 }
 
+#[cfg(feature = "semver")]
+impl Sparsable for Version {
+    fn sparse_init(
+        &mut self,
+        _state: &mut SparseState,
+        _metadata: &SparseMetadata,
+        _depth: u32,
+    ) -> Result<(), SparseError> {
+        Ok(())
+    }
+}
+
+#[cfg(feature = "semver")]
+impl Sparsable for VersionReq {
+    fn sparse_init(
+        &mut self,
+        _state: &mut SparseState,
+        _metadata: &SparseMetadata,
+        _depth: u32,
+    ) -> Result<(), SparseError> {
+        Ok(())
+    }
+}
+
+impl Sparsable for serde_json::Value {
+    fn sparse_init(
+        &mut self,
+        _state: &mut SparseState,
+        _metadata: &SparseMetadata,
+        _depth: u32,
+    ) -> Result<(), SparseError> {
+        Ok(())
+    }
+}
+
 impl<T> Sparsable for Option<T>
 where
     T: Serialize + DeserializeOwned + SparsableTrait,
